<?php

namespace App\Controller\Frontend;

use App\Entity\Dreams;
use App\Entity\ProjectsBoost;
use App\Entity\ProjectsInspiring;
use App\Entity\Revolts;
use Doctrine\ORM\EntityManagerInterface;
use Symfony\Bundle\FrameworkBundle\Controller\AbstractController;
use Symfony\Component\HttpFoundation\Response;
use App\Entity\Site\Page;

class DefaultController extends AbstractController
{
    protected $em;

    public function __construct(EntityManagerInterface $em)
    {
        $this->em = $em;
    }

    public function home()
    {
        return $this->render('frontend/home.html.twig');
    }

    public function cartoInteractive()
    {
        return $this->render(
            'frontend/carto-int.html.twig',
            [
                'nbContrib' => $this->countContrib()
            ]
        );
    }

    public function cartoListe()
    {
        return $this->render(
            'frontend/carto-liste.html.twig',
            [
                'nbContrib' => $this->countContrib()
            ]
        );
    }

    public function cartoCarte()
    {
        return $this->render(
            'frontend/carto-carte.html.twig',
            [
                'nbContrib' => $this->countContrib()
            ]
        );
    }

    public function contact()
    {
        return $this->render('frontend/contact.html.twig');
    }

    public function about()
    {
        return $this->render('frontend/about.html.twig');
    }

    public function contribuate()
    {
        return $this->render(
            'frontend/contribuate.html.twig',
            [
                'nbContrib' => $this->countContrib()
            ]
        );
    }

    public function mention(): Response
    {
        $pageRepository = $this->em->getRepository(Page::class);

        return $this->render(
            'page/page.html.twig',
            [
                'controller_name' => 'IndexController',
                'page' => $pageRepository->findOneByDevAlias('legal-mention')
            ]
        );
    }

    private function countContrib(): int
    {
        $dreamRepository = $this->em->getRepository(Dreams::class);
        $revoltRepository = $this->em->getRepository(Revolts::class);
        $projectsBoostRepository = $this->em->getRepository(ProjectsBoost::class);
        $projectsInspiringRepository = $this->em->getRepository(ProjectsInspiring::class);

        $dreams = count($dreamRepository->findAll());
        $revolts = count($revoltRepository->findAll());
        $projectsBoost = count($projectsBoostRepository->findAll());
        $projectsInspiring = count($projectsBoostRepository->findAll());

        $nbContrib = $dreams + $revolts + $projectsBoost + $projectsInspiring;

        return $nbContrib;
    }

}